==> pantomime-1.0.4.tgz: Local/Headers/Pantomime/IMAPFolder.h <==
/*
**  IMAPFolder.h
**
**  Copyright (c) 2001, 2002
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**          Anthony W. Juckel <awj@digitalgreen.com>
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**  
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**  Lesser General Public License for more details.
**  
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

#import <Foundation/Foundation.h>
#import <Pantomime/Folder.h>

#import <sys/types.h>
#import <sys/socket.h>
#import <netinet/in.h>
#import <netdb.h>

@class Flags;
@class IMAPCacheManager;

@interface IMAPFolder : Folder
{
  IMAPCacheManager *imapCacheManager;

  int uidValidity;
  BOOL selected;
}

- (void) deleteMessageWithUID: (int) theUID;

- (NSData *) prefetchMessageWithUID: (int) theUID;
- (NSData *) prefetchMessageBodyWithUID: (int) theUID;
- (NSData *) prefetchMessageHeadersWithUID: (int) theUID;

- (BOOL) prefetch;
- (BOOL) prefetchNewMessagesStartingAtUID: (int) theUID;
- (NSDictionary *) prefetchMessageFlagsFromUID: (int) startUID 
                                         toUID: (int) endUID;

- (Flags *) fetchMessageFlagsWithUID: (int) theUID;
- (int) fetchMessageSizeWithUID: (int) theUID;
- (int) fetchMessageMSNWithUID: (int) theUID;

- (Flags *) parseMessageFlagsFromString: (NSString *) aString;
- (int) parseMessageSizeFromString: (NSString *) aString;
- (int) parseMessageMSNFromString: (NSString *) aString;
- (int) parseMessageSegmentSizeFromString: (NSString *) aString;
- (int) parseMessageUIDFromString: (NSString *) aString;

- (NSArray *) uncachedUIDStartingAtUID: (int) theUID;

- (void) setMessageFlags: (Flags *) theFlags
                  forUID: (int) theUID;

- (void) noop;

- (int) uidValidity;
- (void) setUIDValidity: (int) theUIDValidity;


- (IMAPCacheManager *) imapCacheManager;
- (void) setIMAPCacheManager: (IMAPCacheManager *) theIMAPCacheManager;

- (BOOL) selected;
- (void) setSelected: (BOOL) aBOOL;

@end


//
// Private methods
//
@interface IMAPFolder (Private)

- (NSData *) _removeInvalidHeadersFromMessage: (NSData *) theMessage;

- (void) _replaceCRLFInMutableData: (NSMutableData *) theMutableData;

- (NSString *) _flagsAsStringFromFlags: (Flags *) theFlags;

- (void) _newMessagesHaveArrived;

@end

==> pantomime-1.1.0.tgz: Local/Headers/Pantomime/IMAPFolder.h <==
/*
**  IMAPFolder.h
**
**  Copyright (c) 2001, 2002, 2003
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**          
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**  
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**  Lesser General Public License for more details.
**  
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

#ifndef _Pantomime_H_IMAPFolder
#define _Pantomime_H_IMAPFolder

#include <Pantomime/Folder.h>

#import <Foundation/NSArray.h>
#import <Foundation/NSData.h>
#import <Foundation/NSString.h>

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>

@class Flags;

@interface IMAPFolder : Folder
{
  int UIDValidity;
  BOOL selected, newMessagesHaveArrived;

  id delegate;
}

- (void) copyMessages: (NSArray *) theMessages
             toFolder: (NSString *) theFolder;

- (BOOL) prefetch;

- (int) UIDValidity;
- (void) setUIDValidity: (int) theUIDValidity;

- (BOOL) selected;
- (void) setSelected: (BOOL) aBOOL;

- (id) delegate;
- (void) setDelegate: (id) theDelegate;

@end


//
// Private methods
//
@interface IMAPFolder (Private)

- (NSString *) _flagsAsStringFromFlags: (Flags *) theFlags;
- (NSData *) _removeInvalidHeadersFromMessage: (NSData *) theMessage;
- (int) _updateMessagesFromUID: (int) startUID 
                         toUID: (int) endUID;
@end

#endif // _Pantomime_H_IMAPFolder
